(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@angular/core'), require('@angular/forms')) :
    typeof define === 'function' && define.amd ? define('ngx-tiptap', ['exports', '@angular/core', '@angular/forms'], factory) :
    (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global['ngx-tiptap'] = {}, global.ng.core, global.ng.forms));
}(this, (function (exports, core, forms) { 'use strict';

    var NgxTiptapDirective = /** @class */ (function () {
        function NgxTiptapDirective(el, _renderer) {
            var _this = this;
            this.el = el;
            this._renderer = _renderer;
            this.outputFormat = 'html';
            this.onChange = function () { };
            this.onTouched = function () { };
            this.handleChange = function (_a) {
                var transaction = _a.transaction;
                if (!transaction.docChanged) {
                    return;
                }
                if (_this.outputFormat === 'html') {
                    _this.onChange(_this.editor.getHTML());
                    return;
                }
                _this.onChange(_this.editor.getJSON());
            };
        }
        // Writes a new value to the element.
        // This methods is called when programmatic changes from model to view are requested.
        NgxTiptapDirective.prototype.writeValue = function (value) {
            if (!value) {
                return;
            }
            if (!this.outputFormat && typeof value === 'string') {
                this.outputFormat = 'html';
            }
            this.editor.chain().setContent(value, false).run();
        };
        // Registers a callback function that is called when the control's value changes in the UI.
        NgxTiptapDirective.prototype.registerOnChange = function (fn) {
            this.onChange = fn;
        };
        // Registers a callback function that is called by the forms API on initialization to update the form model on blur.
        NgxTiptapDirective.prototype.registerOnTouched = function (fn) {
            this.onTouched = fn;
        };
        // Called by the forms api to enable or disable the element
        NgxTiptapDirective.prototype.setDisabledState = function (isDisabled) {
            this.editor.setEditable(!isDisabled);
            this._renderer.setProperty(this.el.nativeElement, 'disabled', isDisabled);
        };
        NgxTiptapDirective.prototype.ngOnInit = function () {
            var _this = this;
            if (!this.editor) {
                throw new Error('Required: Input `editor`');
            }
            // take the inner contents and clear the block
            var innerHTML = this.el.nativeElement.innerHTML;
            this.el.nativeElement.innerHTML = '';
            // insert the editor in the dom
            this.el.nativeElement.appendChild(this.editor.options.element.firstChild);
            // update the options for the editor
            this.editor.setOptions({ element: this.el.nativeElement });
            // update content to the editor
            if (innerHTML) {
                this.editor.chain().setContent(innerHTML, false).run();
            }
            // register blur handler to update `touched` property
            this.editor.on('blur', function () {
                _this.onTouched();
            });
            // register transaction handler to emit changes on update
            this.editor.on('transaction', this.handleChange);
        };
        NgxTiptapDirective.prototype.ngOnDestroy = function () {
            this.editor.destroy();
        };
        return NgxTiptapDirective;
    }());
    NgxTiptapDirective.decorators = [
        { type: core.Directive, args: [{
                    selector: 'tiptap, [tiptap], tiptap-editor, [tiptapEditor]',
                    providers: [{
                            provide: forms.NG_VALUE_ACCESSOR,
                            useExisting: core.forwardRef(function () { return NgxTiptapDirective; }),
                            multi: true
                        }]
                },] }
    ];
    NgxTiptapDirective.ctorParameters = function () { return [
        { type: core.ElementRef },
        { type: core.Renderer2 }
    ]; };
    NgxTiptapDirective.propDecorators = {
        editor: [{ type: core.Input }],
        outputFormat: [{ type: core.Input }]
    };

    var NgxTiptapModule = /** @class */ (function () {
        function NgxTiptapModule() {
        }
        return NgxTiptapModule;
    }());
    NgxTiptapModule.decorators = [
        { type: core.NgModule, args: [{
                    declarations: [
                        NgxTiptapDirective
                    ],
                    exports: [
                        NgxTiptapDirective
                    ]
                },] }
    ];

    /*
     * Public API Surface of ngx-tiptap
     */

    /**
     * Generated bundle index. Do not edit.
     */

    exports.NgxTiptapDirective = NgxTiptapDirective;
    exports.NgxTiptapModule = NgxTiptapModule;

    Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=ngx-tiptap.umd.js.map
